import Vue from 'vue'
import VueRouter from 'vue-router'
import Dashboard from '@/views/Dashboard'
import Welcome from "@/views/Welcome";

import store from '@/store'

Vue.use(VueRouter);

const routes = [
    {
        path: '/welcome',
        name: 'Welcome',
        component: Welcome,
        meta: {
            allowVisit(loggedin) {
                return !loggedin;
            }
        }
    },
    {
        path: '/',
        name: 'Dashboard',
        component: Dashboard,
        meta: {
            allowVisit(loggedin) {
                return loggedin;
            }
        }
    },
    {
        path: '/about',
        name: 'About',
        // route level code-splitting
        // this generates a separate chunk (about.[hash].js) for this route
        // which is lazy-loaded when the route is visited.
        component: () => import(/* webpackChunkName: "about" */ '@/views/About.vue'),
        meta: {
            allowVisit() {
                return true;
            }
        }
    }
]

const router = new VueRouter({
    mode: 'history',
    base: process.env.BASE_URL,
    routes
})


router.beforeEach((to, from, next) => {

    const loggedin = store.getters["auth/isLoggedIn"];

    const visitAllowed = to.matched.some(record => record.meta.allowVisit(loggedin))

    if (visitAllowed) {
        next();
        return;
    }

    if (loggedin) {
        next({name: 'Dashboard'})
    } else {
        next({name: 'Welcome'})
    }

})


export default router
